@@ -7,6 +7,7 @@ import datetime
 import h5py
 from numpy.testing import assert_allclose
 import pytest
+from pysnirf2 import validateSnirf
 
 from mne.datasets.testing import data_path, requires_testing_data
 from mne.utils import requires_h5py, object_diff
@@ -22,6 +23,8 @@ fname_nirx_15_2_short = op.join(data_path(download=False),
                                 'NIRx', 'nirscout',
                                 'nirx_15_2_recording_w_short')
 
+pytest.importorskip('mne', '1.0')  # these tests are broken on 0.24!
+
 
 @requires_h5py
 @requires_testing_data
@@ -37,6 +40,11 @@ def test_snirf_write(fname, tmpdir):
     write_raw_snirf(raw_orig, test_file)
     raw = read_raw_snirf(test_file)
 
+    result = validateSnirf(str(test_file))
+    if result.is_valid():
+        result.display()
+    assert result.is_valid()
+
     # Check annotations are the same
     assert_allclose(raw.annotations.onset, raw_orig.annotations.onset)
     assert_allclose([float(d) for d in raw.annotations.description],
@@ -136,6 +144,6 @@ def _verify_snirf_required_fields(test_file):
 def _verify_snirf_version_str(test_file):
     """Verify that the version string contains the correct spec version."""
     with h5py.File(test_file, 'r') as h5:
-        version_str = h5['/formatVersion'][0].decode('UTF-8')
+        version_str = h5['/formatVersion'][()].decode('UTF-8')
         expected_str = SPEC_FORMAT_VERSION
         assert version_str == expected_str
