@@ -4,19 +4,22 @@
 
 from copy import deepcopy
 from pathlib import PosixPath
+import warnings
 
 import pandas as pd
 import numpy as np
 from numpy import array_equal, where
+from h5io import read_hdf5, write_hdf5
 
-import nilearn.glm
-from nilearn.glm.first_level import run_glm as nilearn_glm
+with warnings.catch_warnings(record=True):
+    warnings.simplefilter('ignore')
+    import nilearn.glm
+    from nilearn.glm.first_level import run_glm as nilearn_glm
 
 from mne.channels.channels import ContainsMixin
 from mne.utils import fill_doc, warn, verbose, check_fname, _validate_type
-from mne.io.pick import _picks_to_idx
+from mne.io.pick import _picks_to_idx, pick_info
 from mne.io.constants import FIFF
-from mne.externals.h5io import read_hdf5, write_hdf5
 from mne import Info
 
 from ..visualisation._plot_GLM_topo import _plot_glm_topo,\
@@ -123,6 +126,8 @@ class _BaseGLM(ContainsMixin):
             Dataframe containing GLM results.
         """
         from ..utils import glm_to_tidy
+        if order is None:
+            order = self.ch_names
         return glm_to_tidy(self.info, self._data, self.design, order=order)
 
     def scatter(self, conditions=[], exclude_no_interest=True, axes=None,
@@ -262,8 +267,7 @@ class RegressionResults(_BaseGLM):
         """
         picks = _picks_to_idx(self.info, picks, 'all', exclude,
                               allow_empty=False)
-        picks = [self.ch_names[p] for p in picks]
-        self.info.pick_channels(picks)
+        pick_info(self.info, picks, copy=False)
         self._data = {key: self._data[key] for key in self.info.ch_names}
         return self
 
@@ -371,12 +375,18 @@ class RegressionResults(_BaseGLM):
             integer indices of ``epochs.ch_names``). For example::
 
                 group_by=dict(Left_ROI=[1, 2, 3, 4], Right_ROI=[5, 6, 7, 8])
-
-            Note that within a dict entry all channels must have the same type.
         condition : str | list
             Name to be used for condition.
-        weighted : Bool
-            Should channels be weighted by inverse of standard error.
+        weighted : Bool | dict
+            Weighting to be applied to each channel in the ROI computation.
+            If False, then all channels will be weighted equally.
+            If True, channels will be weighted by the inverse of
+            the standard error of the GLM fit.
+            For manual specification of the channel weighting a dictionary
+            can be provided.
+            If a dictionary is provided, the keys and length of lists must
+            match the ``group_by`` parameters.
+            The weights will be scaled internally to sum to 1.
         demographic_info : Bool
             Add an extra column with demographic information from
             info["subject_info"].
@@ -389,13 +399,34 @@ class RegressionResults(_BaseGLM):
         if isinstance(condition, str):
             condition = [condition]
 
+        if isinstance(weighted, dict):
+            if weighted.keys() != group_by.keys():
+                raise KeyError("Keys of group_by and weighted "
+                               "must be the same")
+            for key in weighted.keys():
+                if len(weighted[key]) != len(group_by[key]):
+                    raise ValueError("The length of the keys for group_by "
+                                     "and weighted must match")
+                if (np.array(weighted[key]) < 0).any():
+                    raise ValueError("Weights must be positive values")
+
         tidy = pd.DataFrame()
         for cond in condition:
             cond_idx = where([c == cond for c in self.design.columns])[0]
+            if not len(cond_idx):
+                raise KeyError(f'condition {repr(cond)} not found in '
+                               f'self.design.columns: {self.design.columns}')
 
             roi = _glm_region_of_interest(self._data, group_by,
                                           cond_idx, cond, weighted)
-            tidy = tidy.append(roi)
+            tidy = pd.concat([tidy, roi])
+
+        if weighted is True:
+            tidy["Weighted"] = "Inverse standard error"
+        elif weighted is False:
+            tidy["Weighted"] = "Equal"
+        elif isinstance(weighted, dict):
+            tidy["Weighted"] = "Custom"
 
         if demographic_info:
             if 'age' in self.info['subject_info'].keys():
@@ -491,8 +522,13 @@ class RegressionResults(_BaseGLM):
         df = self.to_dataframe(order=self.ch_names)
         if condition is None:
             warn("You must provide a condition to plot", ValueError)
-        df = df.query("Condition in @condition")
-        df = df.query("Chroma in @chroma")
+        df_use = df.query("Condition in @condition")
+        if len(df_use) == 0:
+            raise KeyError(
+                f'condition={repr(condition)} not found in conditions: '
+                f'{sorted(set(df["Condition"]))}')
+        df = df_use
+        df = df.query("Chroma in @chroma").copy()
         df["theta"] = df["theta"] * 1e6
 
         info = self.copy().pick(chroma).info
