@@ -3,10 +3,13 @@
 # License: BSD (3-clause)
 
 import pytest
+import numpy as np
 import mne
 import mne_nirs
-import numpy as np
-from mne.utils import (requires_pysurfer, traits_test)
+
+from mne.datasets import testing
+from mne.utils import catch_logging, check_version
+
 from mne_nirs.experimental_design.tests.test_experimental_design import \
     _load_dataset
 from mne_nirs.experimental_design import make_first_level_design_matrix
@@ -15,20 +18,23 @@ from mne_nirs.visualisation import plot_glm_topo, plot_glm_surface_projection
 from mne_nirs.utils import glm_to_tidy
 
 
-@requires_pysurfer
-@traits_test
-def test_plot_nirs_source_detector_pyvista():
-    mne.viz.set_3d_backend('pyvista')
-    data_path = mne.datasets.testing.data_path() + '/NIRx/nirscout'
-    subjects_dir = mne.datasets.sample.data_path() + '/subjects'
-    raw = mne.io.read_raw_nirx(data_path + '/nirx_15_2_recording_w_short')
+testing_path = testing.data_path(download=False)
+raw_path = testing_path + '/NIRx/nirscout/nirx_15_2_recording_w_short'
+subjects_dir = testing_path + '/subjects'
+
+requires_mne_1 = pytest.mark.skipif(not check_version('mne', '1.0'),
+                                    reason='Needs MNE-Python 1.0')
+
+
+def test_plot_nirs_source_detector_pyvista(requires_pyvista):
+    raw = mne.io.read_raw_nirx(raw_path)
 
     mne_nirs.visualisation.plot_nirs_source_detector(
         np.random.randn(len(raw.ch_names)),
         raw.info, show_axes=True,
         subject='fsaverage',
         trans='fsaverage',
-        surfaces=['brain'],
+        surfaces=['white'],
         fnirs=False,
         subjects_dir=subjects_dir,
         verbose=True)
@@ -38,13 +44,13 @@ def test_plot_nirs_source_detector_pyvista():
         raw.info, show_axes=True,
         subject='fsaverage',
         trans='fsaverage',
-        surfaces=['brain'],
+        surfaces=['white'],
         fnirs=False,
         subjects_dir=subjects_dir,
         verbose=True)
 
 
-@pytest.mark.filterwarnings('ignore:.*nilearn.glm module is experimental.*:')
+@pytest.mark.filterwarnings('ignore:"plot_glm_topo" has been deprecated.*:')
 def test_run_plot_GLM_topo():
     raw_intensity = _load_dataset()
     raw_intensity.crop(450, 600)  # Keep the test fast
@@ -97,7 +103,6 @@ def test_run_plot_GLM_topo():
         plot_glm_topo(raw_haemo, glm_estimates_subset, design_matrix)
 
 
-@pytest.mark.filterwarnings('ignore:.*nilearn.glm module is experimental.*:')
 def test_run_plot_GLM_contrast_topo():
     raw_intensity = _load_dataset()
     raw_intensity.crop(450, 600)  # Keep the test fast
@@ -112,12 +117,15 @@ def test_run_plot_GLM_contrast_topo():
     basic_conts = dict([(column, contrast_matrix[i])
                         for i, column in enumerate(design_matrix.columns)])
     contrast_LvR = basic_conts['A'] - basic_conts['B']
-    contrast = mne_nirs.statistics.compute_contrast(glm_est.data, contrast_LvR)
-    fig = mne_nirs.visualisation.plot_glm_contrast_topo(raw_haemo, contrast)
+    with pytest.deprecated_call(match='comprehensive GLM'):
+        contrast = mne_nirs.statistics.compute_contrast(
+            glm_est.data, contrast_LvR)
+    with pytest.deprecated_call(match='comprehensive GLM'):
+        fig = mne_nirs.visualisation.plot_glm_contrast_topo(
+            raw_haemo, contrast)
     assert len(fig.axes) == 3
 
 
-@pytest.mark.filterwarnings('ignore:.*nilearn.glm module is experimental.*:')
 def test_run_plot_GLM_contrast_topo_single_chroma():
     raw_intensity = _load_dataset()
     raw_intensity.crop(450, 600)  # Keep the test fast
@@ -133,8 +141,12 @@ def test_run_plot_GLM_contrast_topo_single_chroma():
     basic_conts = dict([(column, contrast_matrix[i])
                         for i, column in enumerate(design_matrix.columns)])
     contrast_LvR = basic_conts['A'] - basic_conts['B']
-    contrast = mne_nirs.statistics.compute_contrast(glm_est.data, contrast_LvR)
-    fig = mne_nirs.visualisation.plot_glm_contrast_topo(raw_haemo, contrast)
+    with pytest.deprecated_call(match='comprehensive GLM'):
+        contrast = mne_nirs.statistics.compute_contrast(
+            glm_est.data, contrast_LvR)
+    with pytest.deprecated_call(match='comprehensive GLM'):
+        fig = mne_nirs.visualisation.plot_glm_contrast_topo(
+            raw_haemo, contrast)
     assert len(fig.axes) == 2
 
 
@@ -144,11 +156,9 @@ def test_fig_from_axes():
         _get_fig_from_axes([1, 2, 3])
 
 
-@requires_pysurfer
-@traits_test
-@pytest.mark.filterwarnings('ignore:.*nilearn.glm module is experimental.*:')
-def test_run_plot_GLM_projection():
-    mne.viz.set_3d_backend('pyvista')
+# surface arg
+@requires_mne_1
+def test_run_plot_GLM_projection(requires_pyvista):
     raw_intensity = _load_dataset()
     raw_intensity.crop(450, 600)  # Keep the test fast
 
@@ -165,5 +175,40 @@ def test_run_plot_GLM_projection():
     brain = plot_glm_surface_projection(raw_haemo.copy().pick("hbo"),
                                         df, clim='auto', view='dorsal',
                                         colorbar=True, size=(800, 700),
-                                        value="theta")
+                                        value="theta", surface='white',
+                                        subjects_dir=subjects_dir)
     assert type(brain) == mne.viz._brain.Brain
+
+
+@requires_mne_1
+@pytest.mark.parametrize('fname_raw, to_1020', [
+    (raw_path, False),
+    (raw_path, True),
+])
+def test_plot_3d_montage(requires_pyvista, fname_raw, to_1020):
+    import pyvista
+    pyvista.close_all()
+    assert len(pyvista.plotting._ALL_PLOTTERS) == 0
+    raw = mne.io.read_raw_nirx(fname_raw)
+    if to_1020:
+        need = set(sum(
+            (ch_name.split()[0].split('_') for ch_name in raw.ch_names),
+            list()))
+        mon = mne.channels.make_standard_montage('standard_1020')
+        mon.rename_channels({h: n for h, n in zip(mon.ch_names, need)})
+        raw.set_montage(mon)
+    n_labels = len(raw.ch_names) // 2
+    view_map = {'left-lat': np.arange(1, n_labels // 2),
+                'caudal': np.arange(n_labels // 2, n_labels + 1)}
+    # We use "sample" here even though it's wrong so that we can have a head
+    # surface
+    with catch_logging() as log:
+        mne_nirs.viz.plot_3d_montage(
+            raw.info, view_map, subject='sample', surface='white',
+            subjects_dir=subjects_dir, verbose=True)
+    assert len(pyvista.plotting._ALL_PLOTTERS) == 0
+    log = log.getvalue().lower()
+    if to_1020:
+        assert 'automatically mapped' in log
+    else:
+        assert 'could not' in log
